#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 getopt-generics
version:              0.13.1.0
visibility:           public
id:                   getopt-generics-0.13.1.0-FdShVjoIZnF3HEp6mwDI4y
key:                  getopt-generics-0.13.1.0-FdShVjoIZnF3HEp6mwDI4y
license:              BSD-3-Clause
copyright:            Zalora South East Asia Pte Ltd
maintainer:           linh.nguyen@zalora.com, soenkehahn@gmail.com
author:               Linh Nguyen, Sönke Hahn
homepage:             https://github.com/soenkehahn/getopt-generics#readme
synopsis:             Create command line interfaces with ease
description:          Create command line interfaces with ease
category:             Console, System
abi:                  d27e78232ae7a83c5461c5530ce8d8fd
exposed:              True
exposed-modules:      WithCli WithCli.Pure
hidden-modules:
    WithCli.Argument WithCli.Flag WithCli.HasArguments WithCli.Modifier
    WithCli.Modifier.Types WithCli.Normalize WithCli.Parser
    WithCli.Pure.Internal WithCli.Result Paths_getopt_generics

import-dirs:          /usr/lib/ghc-9.6.6/site-local/getopt-generics-0.13.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/getopt-generics-0.13.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/getopt-generics-0.13.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-getopt-generics
hs-libraries:         HSgetopt-generics-0.13.1.0-FdShVjoIZnF3HEp6mwDI4y
depends:
    base-4.18.2.1 base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4
    base-orphans-0.9.3-20SQzYrHGHAAT4Dnfewc9h
    generics-sop-0.5.1.4-Jm3azQ1bHSLFwLmIcDOhGt
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig

haddock-interfaces:
    /usr/share/doc/haskell-getopt-generics/html/getopt-generics.haddock

haddock-html:         /usr/share/doc/haskell-getopt-generics/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

